PRO fighiaqa,date

;Plots histograms of intensities of quiet and
;active regions in IR and WL average images.

on_error,1
if (date ne 23) and (date ne 25) then  $
   message,'Sorry, I do not know how to handle this dataset'
dat=strtrim(date,2)

if date eq 23 then begin
	qx1=246		; subfield of quiet region
	qx2=379
	qy1=182
	qy2=291
	tp=0.975	;IR threshold int. for pores
	ta=0.022	;threshold for active region in dif.images
	mini=0.9	;limits for histograms
	maxi=1.1
endif else begin
	qx1=304		; subfield of quiet region
	qx2=363
	qy1=135
	qy2=274
	tp=0.975	;IR threshold int. for pores
	ta=0.022	;threshold for active region in dif.images
	mini=0.9	;limits for histograms
	maxi=1.1
endelse

restore,'flows'+dat	;INPUT
si=size(ave)
vm=0
vx=0
vy=0
wm=0
wx=0
wy=0

;extract quiet region

avq=ave(qx1:qx2,qy1:qy2,*)
awq=awe(qx1:qx2,qy1:qy2,*)

;normalization to mean int. of quiet regions

avn=ave
awn=awe
for i=0,si(3)-1 do avn(0,0,i)=ave(*,*,i)/mean(avq(*,*,i))
for i=0,si(3)-1 do awn(0,0,i)=awe(*,*,i)/mean(awq(*,*,i))
avq=avn(qx1:qx2,qy1:qy2,*)
awq=awn(qx1:qx2,qy1:qy2,*)

;excluding mask for pores

bmp=avn gt tp

;differential images

awv=awn-avn*2+1

;mask for active regions, excluding pores

bma=(awv gt ta)*bmp

;active regions

ave=avn*bma
awe=awn*bma

;histograms

histy,avq,xvq,yvq,bin=0.0005,min=mini,max=maxi
histy,awq,xwq,ywq,bin=0.0005,min=mini,max=maxi
histy,ave,xva,yva,bin=0.0005,min=mini,max=maxi
histy,awe,xwa,ywa,bin=0.0005,min=mini,max=maxi

;plotting

set_plot,'ps'
device,file='hiaqa'+dat+'.ps',yoffset=5,ysize=20
!p.multi=[0,0,2,0,0]

plot,xva,yva,psym=10,linestyle=1,thick=3,/xst,  $
	title='INFRARED  1.5542 um',xtitle='Intensity',  $
	ytitle='Normalized frequency',charsiz=1
oplot,xvq,yvq,psym=10,linestyle=0,thick=1

plot,xwa,ywa,psym=10,linestyle=1,thick=3,/xst,  $
	title='WHITE LIGHT  0.8000 um',xtitle='Intensity',  $
	ytitle='Normalized frequency',charsiz=1
oplot,xwq,ywq,psym=10,linestyle=0,thick=1

device,/close
!p.multi=0
set_plot,'x'

;statistics

print,' STATISTICS:'
print,'    IR quiet:'
w=where((avq ge mini) and (avq le maxi))
print,'      mean   =',mean(avq(w))
print,'      stdev  =',stdev(avq(w))
print,'      median =',median(avq(w))
print,'    IR active:'
w=where((ave ge mini) and (ave le maxi))
print,'      mean   =',mean(ave(w))
print,'      stdev  =',stdev(ave(w))
print,'      median =',median(ave(w))
print,'    WL quiet:'
w=where((awq ge mini) and (awq le maxi))
print,'      mean   =',mean(awq(w))
print,'      stdev  =',stdev(awq(w))
print,'      median =',median(awq(w))
print,'    WL active:'
w=where((awe ge mini) and (awe le maxi))
print,'      mean   =',mean(awe(w))
print,'      stdev  =',stdev(awe(w))
print,'      median =',median(awe(w))
print,'  '

END
