PRO backgr,day,num,gc,c6,basg,basc
;
; Reads 'gc' and registered 'c6' images, extracts working subfields,
; determines local minima using 'lextrem_box', and
; fits a surface approximating the umbral background using 'grid_tps'.
;
; INPUTS: day = 16, 19, 20   ...date
;	  num = seq. number
; OUTPUTS: img,imc = working subfields of the original 'gc' and 'c6' images
;	  basg,basc = background surfaces for 'gc' and 'c6'
;
; ROUTINES CALLED: lextrem_box, ocont, grid_tps (IDL)
;
on_error,1

; PATHS AND NAMES =============================================

sday=strtrim(fix(day),2)
dsday=sday		;historical by now
num=string(num,format='(I4.4)')

pa1='/home/msobotka/data/sst03/'
pagc='gc_'+dsday+'/'
pac6='c6_'+dsday+'/'
figc='gc_'+sday+'rr.'+num	; input restored gc
fic6='c6_'+sday+'mm.'+num	; input restored and registered c6

; =============================================================

; Reading
  print,'Reading ',figc,'  ',fic6
  restore2,pa1+pagc+figc,gc
  restore2,pa1+pac6+fic6,c6

; Subfields

case 1 of
  day eq 16: begin
    read,'1st part (1) or 2nd part (2)?: ',di
    if di eq 1 then begin
	gc=gc(390:645,350:625)
	c6=c6(390:645,350:625)
    endif else begin
	gc=gc(340:715,330:705)
	c6=c6(340:715,330:705)
    endelse
  end
  day eq 19: begin
    read,'1st part (1) or 2nd part (2)?: ',di
    if di eq 1 then begin
	gc=gc(142:685,308:691)
	c6=c6(142:685,308:691)
    endif else begin
	gc=gc(525:956,340:867)
	c6=c6(525:956,340:867)
    endelse
  end
  day eq 20: begin
	gc=gc(250:777,350:877)
	c6=c6(250:777,350:877)
  end
  else: message,' Wrong day.'
endcase
si=size(gc)

; Local minima

read,'Size of the box for local minima (pix): ',sb
;tbg=lextrem_box(gc,-1,sb)
tbg=lextrem_box(smooth(gc,3),-1,sb)	;smoothing to remove noise in gc
tbc=lextrem_box(c6,-1,sb)

; Removing bad minima manually - gc

window,0,xs=fix(1.5*si(1)+15),ys=fix(1.5*si(2))
ocont,gc,gc,[0,1]
ocont,gc,gc,[0,1]
oplot,tbg(0,*),tbg(1,*),psym=1

print,'Click left to remove bad minima; right to finish'
curs1:
   cursor,x,y,/data,/down
   x=round(x)
   y=round(y)
   if !err eq 4 then goto,endcurs1
   w=where(abs(tbg(0,*)-x) le 1 and abs(tbg(1,*)-y) le 1,c)
   if c eq 0 then goto,curs1 else tbg(2,w(0))=(-1)  ;mark minimum by -1
   print,x,y,' deleted'
   oplot,[tbg(0,w(0))],[tbg(1,w(0))],psym=1,col=0
   goto,curs1
endcurs1:
w=where(tbg(2,*) ne (-1))	;looking for non-marked minima
tbg=tbg(*,w)			;deleting marked minima

; Adding more minima manually - gc

print,'Click left to add a new minimum; right to finish'
curs2:
   cursor,x,y,/data,/down
   x=round(x)
   y=round(y)
   if !err eq 4 then goto,endcurs2
   stb=size(tbg)
   tbg1=lonarr(3,stb(2)+1)
   tbg1(0,0)=tbg
   tbg1(0,stb(2))=x
   tbg1(1,stb(2))=y
   tbg1(2,stb(2))=gc(x,y)
   tbg=tbg1
   print,x,y,' added'
   oplot,[x],[y],psym=1,col=255
   goto,curs2
endcurs2:
stb=size(tbg)
print,stb(2),' points in gc'

; Removing bad minima manually - c6

window,2,xs=fix(1.5*si(1)+15),ys=fix(1.5*si(2))
ocont,c6,c6,[0,1]
ocont,c6,c6,[0,1]
oplot,tbc(0,*),tbc(1,*),psym=1

print,'Click left to remove bad minima; right to finish'
curs3:
   cursor,x,y,/data,/down
   x=round(x)
   y=round(y)
   if !err eq 4 then goto,endcurs3
   w=where(abs(tbc(0,*)-x) le 1 and abs(tbc(1,*)-y) le 1,c)
   if c eq 0 then goto,curs3 else tbc(2,w(0))=(-1)  ;mark minimum by -1
   print,x,y,' deleted'
   oplot,[tbc(0,w(0))],[tbc(1,w(0))],psym=1,col=0
   goto,curs3
endcurs3:
w=where(tbc(2,*) ne (-1))	;looking for non-marked minima
tbc=tbc(*,w)			;deleting marked minima

; Adding more minima manually - c6

print,'Click left to add a new minimum; right to finish'
curs4:
   cursor,x,y,/data,/down
   x=round(x)
   y=round(y)
   if !err eq 4 then goto,endcurs4
   stb=size(tbc)
   tbc1=lonarr(3,stb(2)+1)
   tbc1(0,0)=tbc
   tbc1(0,stb(2))=x		;adding new point
   tbc1(1,stb(2))=y
   tbc1(2,stb(2))=c6(x,y)
   tbc=tbc1
   print,x,y,' added'
   oplot,[x],[y],psym=1,col=255
   goto,curs4
endcurs4:
stb=size(tbc)
print,stb(2),' points in c6'

; Fitting a surface

basg=grid_tps(tbg(0,*),tbg(1,*),tbg(2,*),ngrid=[si(1),si(2)],  $
	start=[0,0],delta=[1,1])
basc=grid_tps(tbc(0,*),tbc(1,*),tbc(2,*),ngrid=[si(1),si(2)],  $
	start=[0,0],delta=[1,1])
basg=fix(basg)		; to save space; possible for Iph=10000
basc=fix(basc)

wset,0
ocont,gc-basg,gc-basg,[-501,-500]	;warning contour -5% Iph
oplot,tbg(0,*),tbg(1,*),psym=1
wset,2
ocont,c6-basc,c6-basc,[-501,-500]	;warning contour -5% Iph
oplot,tbc(0,*),tbc(1,*),psym=1

END






