PRO guess_scat,aur,r,lam
;
; A rough guess of the scattered light fraction in a sunspot
; with radius R (arcsec). AUR is an input 1D aureole array,
; LAM is input wavelength.
; function CLV is called
;
; METHOD:
; Assuming a sunspot in the central zone of the disk.
;
; Iobs = (1-alpha)*Itrue + alpha*Io,
; where alpha = scattered ligh fraction, Io = photospheric
; intensity at disk center (central zone).
;
; At the limb, alpha can be derived from the aureole.
; Assuming a typical width of the spread function to be 10"-15",
; the measured aureole intensity at the distance r from the
; limb is (very) approximately 
; Iaur(r) = beta(r) * I10,  where
; I10 is the disk intensity at the distance of 10" from the limb.
;
; beta < alpha, because the scattered light at the limb comes only
; from one side, while on the disk comes from the whole spot's
; perimeter. Thus, for a spot of radius r, alpha = 3*beta(r)
;
; So, finally,  alpha(r) = 3*Iaur(r)/I10
;
; ANOTHER GUESS:
; The center disk intensity I0 is extrapolated, using center-to-limb
; variation formula (CLV.PRO). The point used for extrapolation is I10.
; Then, in case of a square sunspot of radius r, alpha(r) = 4*Iaur(r)/I0
; Ajajaj...


scale=0.041		;arcsec per pixel
;----------------------------------------
n=n_elements(aur)

; Determine limb position - maximum gradient

gra=deriv(aur)
ma=max(abs(gra),pli)	;pli=postion of the limb (pixels)

; Find I10, Iaur(r)

d10=round(10/scale)
dr =round(r/scale)

if gra(pli) lt 0 then begin	;disk is on the left
  p10=pli-d10
  pr=pli+dr
endif else begin		;disk is on the right
  p10=pli+d10
  pr=pli-dr
endelse

i10=aur(p10)
ir =aur(pr)
print,' I10 =',i10,'     Iaur(r) =',ir

; Determine disk center intensity

b10=clv(10,lam)
i0=i10/b10
print,' Disk center I0 =',i0
irn=ir/i0
print,' Iaur(r)/I0 =',irn

; Calculate alpha

alpha = 3*ir/i10
print,' Stray light fraction =',alpha,'   or maybe',4*irn

END
