;FUNCTION teplota,i1,i2,mu
;
; Calculation of brightness temperatures from intensities I1, I2
; (units of local Iph)
; and of the color temperature
; for the wavelengths 4507.5 and 6020 A and
; for the heliocentric position MU (scalar).
; OUTPUT: array(3): Tbr1, Tbr2, Tcol 
; Called clv.pro
;

; ================ FUNCTION TEQ1 =====================
;
FUNCTION teq1,x
;
; Used for finding the root of the non-linear equation
; of color temperature.
; The root X is the color 'I2' intensity.
;
 COMMON SHR1,c1,wav1,wav2,iph1,iph2,ci

 a1=alog(c1/(wav1^5*iph1*ci*x)+1.)
 a2=alog(c1/(wav2^5*iph2*x)+1.)
 RETURN,wav1*a1-wav2*a2

END
;
; ================ FUNCTION TEPLOTA ==================


FUNCTION teplota,i1,i2,mu

COMMON SHR1,c1,wav1,wav2,iph1,iph2,ci
te=fltarr(3)

; Constants:

wav1 =4507.5		; wavelength 'gc'
wav2 =6020.0		; wavelength 'c6'
iph1o=0.4138		; disk-center absolute intensity for 'gc'
iph2o=0.3095		; disk-center absolute intensity for 'c6'
c1=1.1903e20		; Planck's law
c2=1.4384e8
x1=0.01			; Range for the color 'I2' intensity
x2=2.

i1=float(i1)
i2=float(i2)

; Absolute intensities at the position 'mu'

iph1=iph1o*CLV(-1,wav1,mu)
iph2=iph2o*CLV(-1,wav2,mu)

; Brightness temperatures

 a1=alog(c1/(wav1^5*iph1*i1)+1.)
 a2=alog(c1/(wav2^5*iph2*i2)+1.)
 te(0)=c2/(wav1*a1)
 te(1)=c2/(wav2*a2)

; Color temperature

ci=i1/i2	;color index
; x=findgen(200)*0.01+0.01
; plot,x,TEQ1(x)
j2=RTBIS(x1,x2,'TEQ1',flg,1.e-5)
; print,'ci, j2 =',ci,j2
if flg eq 0 then RETURN,te
te(2)=c2/(wav2*alog(c1/(wav2^5*iph2*j2)+1.))

RETURN,te

END


